@@ -19,22 +19,15 @@ use Forms::Sflang2_dbc;
 sub new {
     
     my ( $class, $href ) = @_;
-   
    my $self = {
    	gladefolder => $$href{gladefolder},
 	schema => $$href{schema},
    };
-
    	$self->{dbh} = $self->{schema}->storage->dbh;
-
 	$self->{dnav} = Forms::Dnav2->new();
-
    $self->{log} = Log::Log4perl->get_logger(__PACKAGE__);
-
     my $builder = $self->{dnav}->get_builder;
-
       my $rs = $self->{schema}->resultset('Country')->search_rs(undef, {order_by => 'country'});
-
     my $dman =  Gtk2::Ex::DbLinker::DbcDataManager->new({
 			rs => $rs,
 		
@@ -46,25 +39,24 @@ sub new {
 
      $builder->connect_signals($self);
 
-     $self->{linker} = Gtk2::Ex::DbLinker::Form->new({ 
+     $self->{linker} = Gtk2::Ex::DbLinker::Form->new( 
 		    data_manager => $dman,
 		    builder =>  $builder,
 		    rec_spinner => $self->{dnav}->get_object('RecordSpinner'),
   	    	    status_label=>  $self->{dnav}->get_object('lbl_RecordStatus'),
 		    rec_count_label => $self->{dnav}->get_object("lbl_recordCount"),
-	    });
+	    );
 
    
 
-      my $combodata = Gtk2::Ex::DbLinker::DbcDataManager->new({
+      my $combodata = Gtk2::Ex::DbLinker::DbcDataManager->new(
 		   rs =>  $self->{schema}->resultset('Langue')->search_rs(undef, {sort_by => 'langue'}),
-			
-		});
+		);
        
-	$self->{linker}->add_combo({
+	$self->{linker}->add_combo(
     		data_manager => $combodata,
 	    	id => 'mainlangid',
-      });
+      );
   #do not name the toplevel window of the form 'mainwindow', since 
   # it's the name of the top level window in the navigation window
   # and we can't have two identical id in the same widgets tree.
@@ -176,16 +168,16 @@ sub display_tbl {
 		my $name = $class{ $href->{name} };
 		my $rs = $self->{schema}->resultset($name)->search_rs();
 		
-		$data = Gtk2::Ex::DbLinker::DbcDataManager->new({ rs => $rs});
+		$data = Gtk2::Ex::DbLinker::DbcDataManager->new( rs => $rs);
 	}
 	my $f = Forms::Dnav2->new(0);
 	my $scroll = Gtk2::ScrolledWindow->new;
 	$scroll->add ($treeview);
 	$f->add_ctrl($scroll);
-	my $rs = Gtk2::Ex::DbLinker::Datasheet->new({
+	my $rs = Gtk2::Ex::DbLinker::Datasheet->new(
 		treeview => $treeview,
 		data_manager => $data,
-	});
+	);
 	$rs->update();
 	$f->show_all_except(["menubar1"]);
 	$f->set_dataref($rs);
