@@ -1,15 +1,9 @@
 package Forms::Sflang2_dbc;
-
 use strict;
 use warnings;
-
-#use lib "../Gtk2-Ex-DbLinker/lib/";
-
 use Gtk2::Ex::DbLinker::Form;
 use Gtk2::Ex::DbLinker::Datasheet;
-
 use Gtk2::Ex::DbLinker::DbcDataManager;
-
 use Forms::Dnav2;
 
 sub new {
@@ -29,8 +23,6 @@ sub new {
    $self->{dnav}->connect_signal_for("del", \&on_delete_clicked, $self );
    $self->{dnav}->connect_signal_for("apply", \&on_apply_clicked, $self );
 
-
-
 	$self->{builder} =  $self->{dnav}->get_builder;
 
 	   $self->{builder}->add_from_file($self->{gladefolder} . "/sflang2.bld");
@@ -44,49 +36,49 @@ sub new {
 	my $rs = $self->{schema}->resultset('Speak')->search_rs({countryid => $self->{countryid}});
 
 
-	my $dman = Gtk2::Ex::DbLinker::DbcDataManager->new({
+	my $dman = Gtk2::Ex::DbLinker::DbcDataManager->new(
 			rs => $rs,
-			});
+			);
 
-		$self->{sform} = Gtk2::Ex::DbLinker::Form->new({
+		$self->{sform} = Gtk2::Ex::DbLinker::Form->new(
 		data_manager => $dman,
 		builder => $self->{builder},
 		rec_spinner => $self->{dnav}->get_object('RecordSpinner'),
 	    	status_label=>  $self->{dnav}->get_object('lbl_RecordStatus'),
 		rec_count_label => $self->{dnav}->get_object("lbl_recordCount"),
-			});
+			);
 
 		
-		my $combodata = Gtk2::Ex::DbLinker::DbcDataManager->new({
+		my $combodata = Gtk2::Ex::DbLinker::DbcDataManager->new(
 				rs => $self->{schema}->resultset('Langue')->search_rs(undef, { order_by => 'langue' }),
 
-			});
+			);
 		
-		$self->{sform}->add_combo({
+		$self->{sform}->add_combo(
 			data_manager => $combodata,
 		    	id => 'langid',
 			builder => $self->{builder},	
-			});
+			);
 		# 	Rdb::Speak::Manager->get_speaks(query =>[langid => {eq => $self->{langid} }, countryid => {ne => $self->{countryid}}]),
-		my $list =  Gtk2::Ex::DbLinker::DbcDataManager->new({
+		my $list =  Gtk2::Ex::DbLinker::DbcDataManager->new(
 				rs => $self->{schema}->resultset('Speak')->search_rs({langid => $self->{langid}, countryid => {'!=' => $self->{countryid} }}),
-			});
+			);
 
-		 $combodata = Gtk2::Ex::DbLinker::DbcDataManager->new({
+		 $combodata = Gtk2::Ex::DbLinker::DbcDataManager->new(
 				rs => $self->{schema}->resultset('Country')->search_rs(undef, { order_by => 'country'} ),
-			});
+			);
 
 		$self->{dnav}->set_dataref($self->{sform});
 
 		my $tree =  Gtk2::TreeView->new();
 
-		$self->{sf_list} = Gtk2::Ex::DbLinker::Datasheet->new({
+		$self->{sf_list} = Gtk2::Ex::DbLinker::Datasheet->new(
 				treeview => $tree,
 				data_manager => $list,
 				fields => [	{name=>"langid", renderer=>"hidden"},
 			    			{name=>"countryid", renderer => "combo", data_manager=> $combodata, fieldnames => ["countryid", "country"],}
 		          		],
-				});
+				);
 
 		#set up the datasheet
 		#
