@@ -1,7 +1,7 @@
 
 use strict;
 use warnings;
-#use lib qw(lib ../lib/ ../../hg_Gtk2-Ex-DbLinker-DbTools_dev/lib/);
+use lib qw(lib ../lib/ ../../hg_Gtk2-Ex-DbLinker-DbTools/lib/);
 use Gtk2 -init;
 use Log::Log4perl;
   Log::Log4perl->init("log.conf"); 
