@@ -1,7 +1,7 @@
 
 use strict;
 use warnings;
-#use lib qw(lib ../lib/ ../../hg_Gtk2-Ex-DbLinker-DbTools_dev/lib/);
+use lib qw(lib ../lib/ ../../hg_Gtk2-Ex-DbLinker-DbTools/lib/);
 use Gtk2 -init;
 
 #use lib "../lib/";
