@@ -11,7 +11,7 @@ use Forms::Langues2_sqla;
 
 use DBI;
 
-my $dbfile ="./data/ex1";
+my $dbfile ="./data/ex1_1";
 
 my $dbh = DBI->connect ("dbi:SQLite:dbname=$dbfile","","", {  
 		RaiseError       => 1,
