@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 
-our $VERSION     = '0.104';
+our $VERSION     = '0.105';
 $VERSION = eval $VERSION;
 
 1;
@@ -34,12 +34,14 @@ On windows use nmake or dmake instead of make.
 
 The following modules are required in order to use Gtk2::Ex::Linker
 
-	Gtk2::Ex::DbLinker::DbTools => 0.99
+	Gtk2::Ex::DbLinker::DbTools => 0.104
 	DateTime::Format::Strptime => 1.5,
-	Test::More => 0.44,
+	Test::More => 1,
 	Gtk2 => 1.240,
-	Carp => 1.17
-	Log::Log4perl => 1.41
+	Carp => 1.17,
+	Log::Log4perl => 1.41,
+	Data::Dumper' => 2.154,
+	DBD::SQLite'	=> 1.46
 
 Install one of Rose::DB::Object or DBIx::Class if you want to use these orm to access your data.
 
@@ -76,7 +78,7 @@ such as inserting, moving, deleting, etc.
 
 =head1 EXAMPLES
 
-The examples folder (located in the Gtk2-Ex-DbLinker-xxx folder under cpan/build in your perl folders tree) contains four examples that use a sqlite database of three tables: 
+The examples folder (located in the Gtk2-Ex-DbLinker-xxx folder under cpan/build in your perl folders tree) contains five examples that use a sqlite database of three tables: 
 
 =over
 
@@ -110,15 +112,19 @@ For each language, a list gives the others countries where this idiom is spoken.
 
 =item *
 
-C<runeexample2_dbc.pl> uses DBIx::Class. The speaks table primary key is the complete row itself, with the two fields, countryid and langid.
+C<runexample2_dbc.pl> uses DBIx::Class and Gtk2::Ex::DbLinker::DbcDataManager. The speaks table primary key is the complete row itself, with the two fields, countryid and langid.
 
 =item *
 
-C<runeexample2_dbi.pl> uses sql commands and DBI. The speaks table primary key is a counter speaksid (primary key) and the two fields, countryid and langid compose an index which does not allow duplicate rows.
+C<runexample2_sqla.pl uses SQL::Abstract::More and Gtk2::Ex::DbLinker::SqlADataManager. The database is the same as above.
 
 =item *
 
-C<runeexample2_rdb.pl> uses Rose::Data::Object. The database is the same as example 2_dbi.
+C<runexample2_dbi.pl> uses sql commands and Gtk2::Ex::DbLinker::DbiDataManager. The speaks table primary key is a counter speaksid (primary key) and the two fields, countryid and langid compose an index which does not allow duplicate rows.
+
+=item *
+
+C<runexample2_rdb.pl> uses Rose::Data::Object and Gtk2::Ex::DbLinker::RdbDataManager. The database is the same as above.
 
 =back
 
