@@ -466,19 +466,13 @@ sub delete {
 
 sub apply{
 	my $self = shift;
+	my $pkref = ( defined $_[0] ? $_[0] : undef );
 	my $row;
-	my $done;
+	my $done = 1; # by default, changes are done 
 	#we are adding a new record if $pos < 0
 	$self->{log}->debug("apply: pos : " . $self->{pos} );
 	if ($self->{pos}<0){
-		#my $class =  $self->{class};
-		#$row = $class->new;
-		#$self->{dman}->new_row;
-			#push @{$self->{data}}, $row;
-			 # $self->{count} ++;
 		 $self->{log}->debug("New row");
-		 # $self->{dman}->set_row_pos($self->{dman}->row_count);
-		
 	}
 
 	# deleting a (or some) record	
@@ -486,6 +480,8 @@ sub apply{
 		$self->{dman}->set_row_pos($p);
 		$self->{dman}->delete;
 	}
+	#$self->_dman_update_rows($self->{pos2del}) unless ($arg{form_only});
+
 	$self->{log}->debug("items in pos2del: " . scalar @{ $self->{pos2del} } );
 	if (scalar @{$self->{pos2del}}){
 		$self->{pos2del} = [];
@@ -499,76 +495,21 @@ sub apply{
 		}
 		return;
 	}
-	#updating a new or an existing record
-	#foreach widget in the form, get the value from the widget and place it in the field unless it's a primary key 
-	#with an autogenerated value
-	my @pk;
-	$self->{log}->debug("cols: " . join(" ", @{$self->{cols}}));
-	foreach my $id (@{$self->{cols}}){
-		if (exists  $self->{datawidgets}->{$id}){
-			my $w = $self->{datawidgets}->{$id};
-			$self->{log}->debug($self->{datawidgetsName}->{$id});
-			my $coderef = $getter{ $self->{datawidgetsName}->{$id} };
-			
-			my $v  = &$coderef($self, $w );
-		
-			$self->{log}->debug("apply id: $id value: ".  ($v?$v:""));
+	# return value: number of fields updated - don't save if there are none
+	if ( $self->_update_fields( $pkref ) ) {
+		$self->{log}->debug("dman->save");
+		$done = $self->{dman}->save;
+	}
 
-			@pk = $self->{dman}->get_autoinc_primarykeys;
-
-			#if ($id ~~ @pk)  {
-			if (grep /^$id$/, @pk) {
-				$self->{log}->debug("not done because it's a auto incremented pk");
-			} else {
-		
-				$v = ($v eq "" ? undef : $v);
-				$self->{log}->debug($id  . ": value undef") unless ( defined $v);	
-				# if ( defined $v && ( $id ~~ @{$self->{dates_formatted}})){
-				if ( defined $v && defined $self->{hdates_formatted}->{$id}){
-					#my $ff = $self->{dates_formatters_f}->{$id};
-				
-					#my $date = $ff->parse_datetime($v);
-					$v = $self->_format_date(1, $id, $v);
-				
-					# $v = $self->{dates_formatters_db}->{$id}->format_datetime($date);
-					#$v = $self->dateformatter('%Y-%m-%d', $date);
-				}
-
-				if ($self->{pos} < -1 ) {
-					$self->{log}->debug("current row pos: " . $self->{dman}->get_row_pos);
-				# $self->{log}->debug("last row pos: " . $self->{dman}->row_count -1);
-				# $self->{dman}->set_row_pos($self->{dman}->get_row_count);
-					$self->{dman}->set_field($id, $v);
-				} else {
-			
-					$self->{dman}->set_field($id, $v);
-				}
-				 $self->{log}->debug("done");
-			} # not in @pk
-	   }	# if exists
-	   else {
-		$self->{log}->debug($id . " not in data");
-	   }
-	} #foreach
-	$self->{log}->debug("dman->save");
-	$done = $self->{dman}->save;
-	#$self->set_widget_value($pk[0], $self->{dman}->get_field($pk[0]));
-	# $self->{log}->debug("nofm: " . $row->nofm);
-	# $self->set_rs_range;
-
-	#if we were adding a row, put it at the end of the array, and display all the values in the form
-	#ie the value from the user or default value from the database.
+	
+	#fetch the value of the autoinc pk to pass them on after insert.
 	my %pk_val;	
-
+       my @pk =$self->{dman}->get_autoinc_primarykeys;
 
 	for my $pk (@pk) {
 		$self->{log}->debug("Primary Key: " . $pk);
 		my $value = $self->{dman}->get_field($pk);
-		#if (my $ref = eval { $row->can( $pk ) }) {
-			#$value = $row->$ref();
-
 			$pk_val{$pk} = $value;
-		#}
 	}
 			#push @pk_val, $id
 		
@@ -589,10 +530,7 @@ sub apply{
         		$self->{rec_spinner}->set_value($last+1);
 	        	$self->{rec_spinner}->signal_handler_unblock( $self->{rs_value_changed_signal} );
     		}
-       	}# else {
-         #		$self->{changed}=0;
-	
-	 #}
+       	}
 	if ($done) {
 		$self->{changed} = 0;
 		$self->_save_subforms;
@@ -602,6 +540,58 @@ sub apply{
 	return $done;
 }
 
+sub _update_fields {
+	my $self = shift;
+	my @pk = ( defined $_[0] ? @{$_[0]} :  $self->{dman}->get_autoinc_primarykeys);
+	#updating a new or an existing record
+	#foreach widget in the form, get the value from the widget and place it in the field unless it's a primary key 
+	#with an autogenerated value
+	
+	$self->{log}->debug("cols: " . join(" ", @{$self->{cols}}));
+	my $count_updated=0;
+	foreach my $id (@{$self->{cols}}){
+		if (exists  $self->{datawidgets}->{$id}){
+		
+			#@pk = $self->{dman}->get_autoinc_primarykeys;
+			
+			#if ($id ~~ @pk)  {
+			if (grep /^$id$/, @pk) {
+				$self->{log}->debug("not done because it's a pk");
+			} else {
+				my $w = $self->{datawidgets}->{$id};
+				$self->{log}->debug($self->{datawidgetsName}->{$id});
+				my $coderef = $getter{ $self->{datawidgetsName}->{$id} };
+				my $v  = &$coderef($self, $w );
+				$self->{log}->debug("_update_fields id: $id value: ".  ($v?$v:""));
+				$v = ($v eq "" ? undef : $v);
+				$self->{log}->debug($id  . ": value undef") unless ( defined $v);	
+				# if ( defined $v && ( $id ~~ @{$self->{dates_formatted}})){
+				if ( defined $v && defined $self->{hdates_formatted}->{$id}){
+					#my $ff = $self->{dates_formatters_f}->{$id};
+				
+					#my $date = $ff->parse_datetime($v);
+					$v = $self->_format_date(1, $id, $v);
+				
+					# $v = $self->{dates_formatters_db}->{$id}->format_datetime($date);
+					#$v = $self->dateformatter('%Y-%m-%d', $date);
+				}
+
+				if ($self->{pos} < -1 ) {
+					$self->{log}->debug("current row pos: " . $self->{dman}->get_row_pos);
+				}
+				$count_updated++;
+				$self->{dman}->set_field($id, $v);
+				 $self->{log}->debug("done");
+			} # not in @pk
+	   }	# if exists
+	   else {
+		$self->{log}->debug($id . " not in data");
+	   }
+	} #foreach
+
+	return $count_updated;
+}
+
 sub next{
 	my $self = shift;
 	if ($self->{auto_apply} && $self->has_changed){ $self->apply;}
@@ -1231,6 +1221,11 @@ C<apply():>
 
 Save a new row, save changes on an existing row, or delete the row(s) marked for deletion.
 
+=item *
+C<apply( [fieldname1, fieldname2 ...] ):>
+
+When inserting a new row, you can pass an array ref of fieldnames that will not be saved to the database. This is usefull to exclude composed primary keys from being saved when this has been done by saving these values directly with the DbiDM or SqlADM with C<dman->save({pk1=> value1, pk2=> value2});>
+
 =item *
 
 C<undo();>
